package com.chinaitop.depot.supervise.controller;

import com.chinaitop.depot.supervise.service.GrainConditionService;
import com.chinaitop.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 获取温湿度数据类
 * 目前该类为直接调用jckz一体化的数据表
 * @author mafy
 */
@RestController
@RequestMapping(value = "/grainCondition")
@Api(description = "温湿度数据类")
public class GrainConditionController {

    @Resource
    private GrainConditionService grainConditionService;

    /**
     * 获取最新仓房温度列表
     * @return
     */
    @RequestMapping(value = "/getDataList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="最新仓房温度列表", notes = "获取最新仓房温度列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseNo", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query")
    })
    public PageInfo<Map<String,Object>> getDataList(Integer pageNum, Integer pageSize,String houseNo, String orgId){
        PageHelper.startPage(pageNum, pageSize);
        List<Map<String,Object>> retList = grainConditionService.getDataList(houseNo, orgId);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<Map<String,Object>>(retList);
        return pageInfo;
    }

    /**
     * 通过cfbh获取当天的三温数据，查询当天的列表数据，按时间排序
     * @param orgId 库id
     * @param barnNumber 仓房编号
     * @param dayCount 显示的天数，从当前时间往前推
     * @return
     */
    @RequestMapping(value = "/getThreeCondition", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="当天的三温数据", notes = "通过cfbh获取当天的三温数据，查询当天的列表数据，按时间排序")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query"),
            @ApiImplicitParam(name = "barnNumber", value = "仓房编号", paramType = "query"),
            @ApiImplicitParam(name = "dayCount", value = "显示的天数，从当前时间往前推", paramType = "query")
    })
    public List<Map<String, Object>> getThreeCondition(Integer orgId,String barnNumber,Integer dayCount) {
        Map<String, Object> byMonth = new HashMap<String, Object>();//基础信息
        byMonth.put("orgid", orgId);
        if(ParameterUtil.isnotnull(barnNumber)){
            byMonth.put("houseid", barnNumber);
        }else{
            byMonth.put("houseid", 1);
        }
        if(ParameterUtil.isnotnull(dayCount)){
            byMonth.put("dayCount", dayCount);
        }else {
            byMonth.put("dayCount", 7);
        }
        List<Map<String, Object>> SelectDay = grainConditionService.getThreeCondition(byMonth);
        return SelectDay;
    }

    /**
     * 通过cfbh获取当年的三温数据
     * @param orgId 库id
     * @param barnNumber 仓房编号
     * @return
     */
    @RequestMapping(value = "/getThreeConditionYear", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="当年的三温数据", notes = "通过cfbh获取当年的三温数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query"),
            @ApiImplicitParam(name = "barnNumber", value = "仓房编号", paramType = "query")
    })
    public List<Map<String, Object>> getThreeConditionYear(Integer orgId,String barnNumber) {
        return grainConditionService.getThreeConditionYear(orgId,barnNumber);
    }

    /**
     * 通过cfbh获取当天的三温数据，查询当天的列表数据，按时间排序--首页用到
     * @param orgId 库id
     * @param barnNumber 仓房编号
     * @return
     */
    @RequestMapping(value = "/getThreeConditionHomePage", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="当天的三温数据--首页用到", notes = "通过cfbh获取当天的三温数据，查询当天的列表数据，按时间排序--首页用到")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query"),
            @ApiImplicitParam(name = "barnNumber", value = "仓房编号", paramType = "query")
    })
    public List<Map<String, Object>> getThreeConditionHomePage(Integer orgId,String barnNumber) {
        Map<String, Object> byMonth = new HashMap<String, Object>();//基础信息
        byMonth.put("orgid", orgId);
        byMonth.put("houseid", barnNumber);
        List<Map<String, Object>> SelectDay = grainConditionService.getThreeConditionHomePage(byMonth);
        return SelectDay;
    }

    /**
     *根据仓房id查询品种,性质
     * 传入仓id
     */
    @RequestMapping(value = "/getTempByHouseNo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="仓房数据", notes = "根据仓房编号查询品种,性质")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseNo", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query"),
            @ApiImplicitParam(name = "houseCode", value = "仓房Code", paramType = "query")
    })
    public Map<String,Object> getTempByHouseNo(String houseNo,String orgId,String houseCode){
        return grainConditionService.getTempByHouseNo(houseNo,orgId,houseCode);
    }


     /**
     * 给pad端提供的获取三温图的接口，
     * @param orgId 库id
     * @param barnNumber 仓房编号
     * @param dayCount 显示的天数，从当前时间往前推
     * @return
     */
    @RequestMapping(value = "/getThreeConditionForPad", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="三温图的接口", notes = "给pad端提供的获取三温图的接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query"),
            @ApiImplicitParam(name = "barnNumber", value = "仓房编号", paramType = "query"),
            @ApiImplicitParam(name = "dayCount", value = "显示的天数，从当前时间往前推", paramType = "query")
    })
    public List<Map<String, Object>> getThreeConditionForPad(Integer orgId,String barnNumber,Integer dayCount){

        Map<String, Object> byMonth = new HashMap<String, Object>();//基础信息

        byMonth.put("orgid",orgId);
        byMonth.put("houseCode", barnNumber);
        byMonth.put("dayCount", dayCount);
        List<Map<String, Object>> SelectDay = grainConditionService.getThreeConditionForPad(byMonth);
        return SelectDay;
    }
}
