package com.chinaitop.depot.supervise.service.impl;


import com.chinaitop.depot.supervise.mapper.TTestdataYearMapper;
import com.chinaitop.depot.supervise.mapper.TestDatasMapper;
import com.chinaitop.depot.supervise.model.TTestdataYear;
import com.chinaitop.depot.supervise.model.TTestdataYearExample;
import com.chinaitop.depot.supervise.service.GrainConditionService;
import com.chinaitop.utils.ParameterUtil;
import com.chinaitop.utils.activiti.StringUtils;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

@Service
public class GrainConditionServiceImpl implements GrainConditionService {

    @Resource
    private TestDatasMapper testDatasMapper;
    @Resource
    private TTestdataYearMapper tTestdataYearMapper;

    /**
     * 获取最新仓房温度列表
     *
     * @return
     */
    @Override
    public List<Map<String, Object>> getDataList(String houseNo, String orgId) {
        Map<String,String> map = new HashMap<String, String>();
        if(!StringUtils.isEmpty(houseNo)){
            map.put("houseNo",houseNo);
        }
        map.put("orgId",orgId);
        return testDatasMapper.getDataList(map);
    }

    /**
     * 根据仓房id查询品种,性质
     * @param houseId
     * @return
     */
    @Override
    public Map<String, Object> getTempByHouseNo(String houseId,String orgId,String houseCode) {
        Map<String,String> map = new HashMap<>();
        map.put("houseId",houseId);
        map.put("orgId",orgId);
        map.put("houseCode",houseCode);
        return testDatasMapper.getTempByHouseNo(map);
    }

    /**
     * 根据仓房BH获取三温曲线图
     * @param map
     * @return
     */
    @Override
    public List<Map<String,Object>> getThreeCondition(Map<String,Object> map) {
        if(ParameterUtil.isequal("YG",map.get("houseid").toString().substring(0,2))){
            return testDatasMapper.selectYGByDays(map);
        }else{
            return testDatasMapper.selectByDays(map);
        }
    }

    @Override
    public List<Map<String,Object>> getThreeConditionYear(Integer orgId,String barnNumber) {
        List<Map<String, Object>> testYear = new ArrayList<Map<String,Object>>();
        Map<String, Object> byMonth = new HashMap<String, Object>();//基础信息
        TTestdataYearExample example = new TTestdataYearExample();
        TTestdataYearExample.Criteria criteria = example.createCriteria();

        //添加查询条件
        byMonth.put("orgid", orgId);
        criteria.andOrgIdEqualTo(orgId.toString());
        byMonth.put("houseCode", barnNumber);
        criteria.andStorehouseEqualTo(barnNumber);

        //判断年粮情表是否有数据
        //如果没有数据则重新查询并存储到年粮情表，以便下回使用
        //有数据，并且数据和查询时间在同一周就直接用
        //否则就，查询最新数据，并存储到年粮情表，以便下回使用
        List<TTestdataYear> tTestdataYears = tTestdataYearMapper.selectByExample(example);
        if (ParameterUtil.isequal(0, tTestdataYears.size())) {
            testYear = testDatasMapper.selectByYear(byMonth);
            TTestdataYear tTestdataYear = new TTestdataYear();
            tTestdataYear.setOrgId(orgId.toString());
            tTestdataYear.setStorehouse(barnNumber);
            tTestdataYear.setQueryTime(new Date());
            tTestdataYear.setTemperatureData(ParameterUtil.ListToString(testYear));

            tTestdataYearMapper.insert(tTestdataYear);
        } else if (ParameterUtil.isSameDate(tTestdataYears.get(0).getQueryTime(), new Date())) {
            testYear = ParameterUtil.StringToList(tTestdataYears.get(0).getTemperatureData());
        } else {
            testYear = testDatasMapper.selectByYear(byMonth);
            tTestdataYears.get(0).setQueryTime(new Date());
            tTestdataYears.get(0).setTemperatureData(ParameterUtil.ListToString(testYear));
            tTestdataYearMapper.updateByPrimaryKeySelective(tTestdataYears.get(0));
        }

        return testYear;
    }

    /**
     * 根据仓房BH获取三温曲线图--首页用到
     * @param example
     * @return
     */
    @Override
    public List<Map<String,Object>> getThreeConditionHomePage(Map<String,Object> example) {
        return testDatasMapper.selectByHours(example);
    }

    /**
     * 给pad端提供的三温图的数据接口
     *
     * @param example
     * @return
     */
    @Override
    public List<Map<String, Object>> getThreeConditionForPad(Map<String, Object> example) {
        example.put("dayNum",Integer.parseInt(example.get("dayCount").toString())-1);
        String houseMaxTime = testDatasMapper.selectHouseMaxTime(example);
        int days = Integer.parseInt(example.get("dayCount").toString());
        example.put("houseMaxTime",houseMaxTime);
        List<Map<String,Object>> three = testDatasMapper.getThreeConditionForPad(example);
        List<Map<String,Object>> threeTemperature = new ArrayList<Map<String,Object>>();
        String times;//获取最新检测时间，如果没有数据则获取当天
        if(three.size() == 0){
            times = ParameterUtil.getSysDate();
        }else{
            times = ObjectUtils.toString(three.get(0).get("days"));
        }
        for(int i = 0;i<days;i++){
            Map<String, Object> mapList = new HashMap<String, Object>();
            mapList.put("days",times);
            mapList.put("lswd",null);
            mapList.put("cwwd",null);
            mapList.put("cnwd",null);
            threeTemperature.add(mapList);
            times = ParameterUtil.dellOneDay(times);//时间减一天存入
        }

        if(three.size() != 0){
            String maxTime = ObjectUtils.toString(three.get(0).get("days"));
            int index = 0;
            for (Map<String,Object> maps:three){
                String dateList = ObjectUtils.toString(maps.get("days"));
                for(int i = index;i<days;i++){
                    if (ParameterUtil.isequal(dateList,maxTime)){
                        threeTemperature.set(i,maps);
                        break;
                    }
                    index++;
                    maxTime = ParameterUtil.dellOneDay(maxTime);//时间减一天存入
                }
            }
        }

        return threeTemperature;
    }
}
